==> ci-auto-update-5.0.4.zip: elabftw_ynh/README_gl.md <==
<!--
NOTA: Este README foi creado automáticamente por <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
NON debe editarse manualmente.
-->

# eLabFTW para YunoHost

[![Nivel de integración](https://dash.yunohost.org/integration/elabftw.svg)](https://dash.yunohost.org/appci/app/elabftw) ![Estado de funcionamento](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![Estado de mantemento](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![Instalar eLabFTW con YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[Le este README en outros idiomas.](./ALL_README.md)*

> *Este paquete permíteche instalar eLabFTW de xeito rápido e doado nun servidor YunoHost.*  
> *Se non usas YunoHost, le a [documentación](https://yunohost.org/install) para saber como instalalo.*

## Vista xeral

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**Versión proporcionada:** 5.0.4~ynh1

**Demo:** <https://demo.elabftw.net/login.php>

## Capturas de pantalla

![Captura de pantalla de eLabFTW](./doc/screenshots/screen-1.jpg)

## Documentación e recursos

- Web oficial da app: <https://www.elabftw.net>
- Documentación oficial para admin: <https://doc.elabftw.net/>
- Repositorio de orixe do código: <https://github.com/elabftw/elabftw>
- Tenda YunoHost: <https://apps.yunohost.org/app/elabftw>
- Informar dun problema: <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## Info de desenvolvemento

Envía a túa colaboración á [rama `testing`](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing).

Para probar a rama `testing`, procede deste xeito:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
ou
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**Máis info sobre o empaquetado da app:** <https://yunohost.org/packaging_apps>

==> ci-auto-update-5.1.2.zip: elabftw_ynh/README_gl.md <==
<!--
NOTA: Este README foi creado automáticamente por <https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
NON debe editarse manualmente.
-->

# eLabFTW para YunoHost

[![Nivel de integración](https://dash.yunohost.org/integration/elabftw.svg)](https://ci-apps.yunohost.org/ci/apps/elabftw/) ![Estado de funcionamento](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![Estado de mantemento](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![Instalar eLabFTW con YunoHost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[Le este README en outros idiomas.](./ALL_README.md)*

> *Este paquete permíteche instalar eLabFTW de xeito rápido e doado nun servidor YunoHost.*  
> *Se non usas YunoHost, le a [documentación](https://yunohost.org/install) para saber como instalalo.*

## Vista xeral

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**Versión proporcionada:** 5.1.2~ynh1

**Demo:** <https://demo.elabftw.net/login.php>

## Capturas de pantalla

![Captura de pantalla de eLabFTW](./doc/screenshots/screen-1.jpg)

## Documentación e recursos

- Web oficial da app: <https://www.elabftw.net>
- Documentación oficial para admin: <https://doc.elabftw.net/>
- Repositorio de orixe do código: <https://github.com/elabftw/elabftw>
- Tenda YunoHost: <https://apps.yunohost.org/app/elabftw>
- Informar dun problema: <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## Info de desenvolvemento

Envía a túa colaboración á [rama `testing`](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing).

Para probar a rama `testing`, procede deste xeito:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
ou
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**Máis info sobre o empaquetado da app:** <https://yunohost.org/packaging_apps>
